Crate enum_info

Crate enum_info 

enum-info is a crate to generate an enum impl which can tell you the number of – and, in most cases, list the – variants in an enum.

Attribute Macros

enum_info
Generates an item impl with a guaranteed variant_count method and an associated constant, VARIANTS, for enums whose variants are all unit-like.